**Example 1: 升级云数据库实例版本**

升级云数据库实例版本

Input: 

```
tccli cdb UpgradeDBInstanceEngineVersion --cli-unfold-argument  \
    --InstanceId cdb-8qrg9t04 \
    --EngineVersion 5.7
```

Output: 
```
{
    "Response": {
        "RequestId": "6EF60BEC-0242-43AF-BB20-270359FB54A7",
        "AsyncRequestId": "d2baf2fb-cbae62df-7dd0d736-9cbd3e31"
    }
}
```

